pub struct Applications<'c> { /* private fields */ }Implementations
Sourceimpl Applications<'_>
impl Applications<'_>
Sourcepub async fn list(&self) -> Result<Vec<Application>>
pub async fn list(&self) -> Result<Vec<Application>>
List all applications
Sourcepub async fn get(
&self,
application_name: impl Into<String> + Send,
) -> Result<Application>
pub async fn get( &self, application_name: impl Into<String> + Send, ) -> Result<Application>
Get details of an application.
Sourcepub async fn subscribe(&self, request: SubscribeRequest) -> Result<Application>
pub async fn subscribe(&self, request: SubscribeRequest) -> Result<Application>
Subscribe an application to an event source. Implementation Notes Returns the state of the application after the subscriptions have changed
Sourcepub async fn unsubscribe(
&self,
request: UnSubscribeRequest,
) -> Result<Application>
pub async fn unsubscribe( &self, request: UnSubscribeRequest, ) -> Result<Application>
Unsubscribe an application from an event source. Implementation Notes Returns the state of the application after the subscriptions have changed
Sourcepub async fn filter_events(
&self,
request: FilterEventsRequest,
) -> Result<Application>
pub async fn filter_events( &self, request: FilterEventsRequest, ) -> Result<Application>
Filter application events types
Allowed and/or disallowed event type filtering can be done.