pub struct AddChannelRequest { /* private fields */ }Implementations
Sourceimpl AddChannelRequest
impl AddChannelRequest
Sourcepub fn with_absorb_dtmf(self, value: impl Into<bool>) -> Self
pub fn with_absorb_dtmf(self, value: impl Into<bool>) -> Self
Absorb DTMF coming from this channel, preventing it to pass through to the bridge
Sourcepub fn with_mute(self, value: impl Into<bool>) -> Self
pub fn with_mute(self, value: impl Into<bool>) -> Self
Mute audio from this channel, preventing it to pass through to the bridge.
Sourcepub fn with_inhibit_connected_line_updates(self, value: impl Into<bool>) -> Self
pub fn with_inhibit_connected_line_updates(self, value: impl Into<bool>) -> Self
Do not present the identity of the newly connected channel to other bridge members.