pub struct CreateRequest { /* private fields */ }Implementations
Sourceimpl CreateRequest
impl CreateRequest
Sourceimpl CreateRequest
impl CreateRequest
Sourcepub fn with_channel_id(self, value: impl Into<String>) -> Self
pub fn with_channel_id(self, value: impl Into<String>) -> Self
The unique id to assign the channel on creation.
Sourcepub fn with_other_channel_id(self, value: impl Into<String>) -> Self
pub fn with_other_channel_id(self, value: impl Into<String>) -> Self
The unique id to assign the second channel when using local channels.
Sourcepub fn with_originator(self, value: impl Into<String>) -> Self
pub fn with_originator(self, value: impl Into<String>) -> Self
Unique ID of the calling channel
Sourcepub fn with_formats(self, value: impl Into<Vec<String>>) -> Self
pub fn with_formats(self, value: impl Into<Vec<String>>) -> Self
The format name capability list to use if originator is not specified. Ex. “ulaw,slin16”.
Format names can be found with “core show codecs”.
Sourcepub fn with_variables(self, value: impl Into<Value>) -> Self
pub fn with_variables(self, value: impl Into<Value>) -> Self
The “variables” key in the body object holds variable key/value pairs to set on the channel on creation.
Other keys in the body object are interpreted as query parameters. Ex. { “endpoint”: “SIP/Alice”, “variables”: { “CALLERID(name)”: “Alice” } }