pub struct ReferRequest { /* private fields */ }Implementations
Sourceimpl ReferRequest
impl ReferRequest
Sourceimpl ReferRequest
impl ReferRequest
Sourcepub fn with_to_self(self, value: impl Into<bool>) -> Self
pub fn with_to_self(self, value: impl Into<bool>) -> Self
If true and “refer_to” refers to an Asterisk endpoint, the “refer_to” value is set to point to this Asterisk endpoint - so the referee is referred to Asterisk. Otherwise, use the contact URI associated with the endpoint.
Sourcepub fn with_variables(self, value: impl Into<Value>) -> Self
pub fn with_variables(self, value: impl Into<Value>) -> Self
The “variables” key in the body object holds technology specific key/value pairs to append to the message.
These can be interpreted and used by the various resource types; for example, the pjsip resource type will add the key/value pairs as SIP headers. The “display_name” key is used by the PJSIP technology. Its value will be prepended as a display name to the Refer-To URI.