pub struct SendMessageToEndpointRequest { /* private fields */ }Implementations
Sourceimpl SendMessageToEndpointRequest
impl SendMessageToEndpointRequest
Sourcepub fn with_variables(self, value: impl Into<Value>) -> Self
pub fn with_variables(self, value: impl Into<Value>) -> Self
The “variables” key in the body object holds technology specific key/value pairs to append to the message.
These can be interpreted and used by the various resource types; for example, the pjsip resource type will add the key/value pairs as SIP headers. The “display_name” key is used by the PJSIP technology. Its value will be prepended as a display name to the Refer-To URI.