pub struct Peer {
pub peer_status: String,
pub cause: Option<String>,
pub address: Option<String>,
pub port: Option<String>,
pub time: Option<String>,
}Expand description
Detailed information about a remote peer that communicates with Asterisk.
Fields
peer_status: StringThe current state of the peer. Note that the values of the status are dependent on the underlying peer technology.
cause: Option<String>An optional reason associated with the change in peer_status.
address: Option<String>The IP address of the peer.
port: Option<String>The port of the peer.
time: Option<String>The last known time the peer was contacted.